#ifndef ALLURE_H
#define ALLURE_H

/**
	* @brief  Configure la girouette pour la dtection de l'allure (sens du vent).
  * @note   Configuration des ports PA6 et 7 en alternate input pour rcuprer les signaux
						Configuration des deux channels du TIM3 pour le compteur incrementeur 
						Configuration du PA5 avec une interruption pour capter les tours de girouette
	* @param  None
  * @retval None
  */
void ConfAllure(void);

/**
	* @brief  Renvoi la valeur de l'allure actuelle
  * @note   Reprsentation de la donne en degrs -> int entre -180 et 180 
						ATTENTION : -1000 renvoy si girouette non initialise
	* @param  None
  * @retval L'allure, reprsent en degrs par un entier entre -180 et 180
						ATTENTION : -1000 renvoy si girouette non initialise
  */
int RecupAllure(void);

/**
	* @brief  Associe un chaine de caractre a une valeur d'allure.
  * @note   Une chaine de caractre est associ a des intervalles de alpha : 
						 [-45, 45]   -> "Vent debout"
						 [45, 55]    -> "Prs"  (et intervalle oppos)
						 [55, 65]    -> "Bon plein"  (et intervalle oppos)
						 [65, 80]    -> "Petit largue"  (et intervalle oppos)
						 [80, 100]   -> "Travers"  (et intervalle oppos)
						 [100, 115]  -> "Largue"  (et intervalle oppos)
						 [115, 155]  -> "Grand largue"  (et intervalle oppos)
						 [155, -155] -> "Vent arrire"
						 Autre       -> "ERROR"
	* @param  alpha : un entier reprsentant l'allure en  (-180  180)
  * @retval Une chaine de caractre reprsentant l'allure
  */
char * ToString(int alpha);

#endif
